@@ -14,7 +14,7 @@
  * all claims, expenses, losses, damages and costs any user may incur
  * as a result of using, copying or modifying the software.
  *
- * $Id: tcldom.c,v 1.18 2002/10/31 23:40:06 andreas_kupries Exp $
+ * $Id: tcldom.c,v 1.20 2003/03/09 11:12:41 balls Exp $
  *
  */
 
@@ -121,6 +121,7 @@ Tcldom_Init (interp)
       Tcl_Interp *interp; /* Interpreter to initialise. */
 {
   extern TcldomStubs tcldomStubs;
+  Tcl_Obj *objPtr;
 
 #ifdef USE_TCL_STUBS
   if (Tcl_InitStubs(interp, "8.1", 0) == NULL) {
@@ -139,6 +140,13 @@ Tcldom_Init (interp)
   Tcl_CreateObjCommand(interp, "dom::element", TclDOMElementCmd, NULL, NULL);
 
   Tcl_SetVar(interp, "::dom::strictDOM", "0", TCL_GLOBAL_ONLY);
+  Tcl_SetVar(interp, "::dom::maxSpecials", "10", TCL_GLOBAL_ONLY);
+  objPtr = Tcl_NewListObj(0, NULL);
+  Tcl_ListObjAppendElement(interp, objPtr, Tcl_NewIntObj(2));
+  Tcl_ListObjAppendElement(interp, objPtr, Tcl_NewStringObj("        ", -1));
+  Tcl_ListObjAppendElement(interp, objPtr, Tcl_NewStringObj("\t", -1));
+  Tcl_SetVar2Ex(interp, "::dom::indentspec", NULL, objPtr, TCL_GLOBAL_ONLY);
+  Tcl_SetVar(interp, "::dom::xmlnsURI", "http://www.w3.org/2000/xmlns/", TCL_GLOBAL_ONLY);
 
   #if TCL_DOES_STUBS
     {
@@ -181,14 +189,22 @@ TclDOM_Register (interp, impl)
   int new;
   Tcl_HashEntry *entryPtr;
 
+  if (impl == NULL) {
+    Tcl_SetResult(interp, "invalid implementation", NULL);
+    return TCL_ERROR;
+  }
+  if (impl->type == NULL) {
+    Tcl_SetResult(interp, "invalid implementation type", NULL);
+    return TCL_ERROR;
+  }
+  if (impl->name == NULL) {
+    Tcl_SetResult(interp, "invalid implementation name", NULL);
+    return TCL_ERROR;
+  }
+
   entryPtr = Tcl_CreateHashEntry(&registeredImplementations, (char *)impl->type, &new);
   if (!new) {
-    Tcl_Obj *ptr = Tcl_NewStringObj("implementation \"", -1);
-    Tcl_AppendObjToObj(ptr, impl->name);
-    Tcl_AppendObjToObj(ptr, Tcl_NewStringObj("\" already registered", -1));
-
-    Tcl_ResetResult(interp);
-    Tcl_SetObjResult(interp, ptr);
+    Tcl_AppendResult(interp, "implementation \"", impl->name, "\" already registered", NULL);
     return TCL_ERROR;
   }
 
@@ -368,7 +384,7 @@ TclDOMDOMImplementationCmd(dummy, interp, objc, objv)
 
       newobjv[0] = Tcl_NewStringObj("dom::tcl::create", -1);
       newcmd     = Tcl_NewListObj(objc, objv);
-      if (Tcl_ListObjReplace(interp, newcmd, 0, 1, 1, newobjv) != TCL_OK) {
+      if (Tcl_ListObjReplace(interp, newcmd, 0, 2, 1, newobjv) != TCL_OK) {
 	return TCL_ERROR;
       }
       if (Tcl_GlobalEvalObj(interp, newcmd) != TCL_OK) {
@@ -430,7 +446,7 @@ TclDOMDOMImplementationCmd(dummy, interp, objc, objv)
       newobjv[0] = Tcl_NewStringObj("dom::tcl::parse", -1);
       newobjv[1] = NULL;
       newcmd = Tcl_NewListObj(objc, objv);
-      if (Tcl_ListObjReplace(interp, newcmd, 0, 1, 1, newobjv) != TCL_OK)
+      if (Tcl_ListObjReplace(interp, newcmd, 0, 2, 1, newobjv) != TCL_OK)
 	return TCL_ERROR;
       if (Tcl_GlobalEvalObj(interp, newcmd) != TCL_OK)
 	return TCL_ERROR;
@@ -454,7 +470,7 @@ TclDOMDOMImplementationCmd(dummy, interp, objc, objv)
       newobjv[0] = Tcl_NewStringObj("dom::tcl::DOMImplementation", -1);
       newobjv[1] = NULL;
       newcmd = Tcl_NewListObj(objc, objv);
-      if (Tcl_ListObjReplace(interp, newcmd, 0, 1, 1, newobjv) != TCL_OK)
+      if (Tcl_ListObjReplace(interp, newcmd, 0, 2, 1, newobjv) != TCL_OK)
 	return TCL_ERROR;
       if (Tcl_GlobalEvalObj(interp, newcmd) != TCL_OK)
 	return TCL_ERROR;
@@ -479,7 +495,7 @@ TclDOMDOMImplementationCmd(dummy, interp, objc, objv)
       newobjv[0] = Tcl_NewStringObj("dom::tcl::serialize", -1);
       newobjv[1] = NULL;
       newcmd = Tcl_NewListObj(objc, objv);
-      if (Tcl_ListObjReplace(interp, newcmd, 0, 1, 1, newobjv) != TCL_OK)
+      if (Tcl_ListObjReplace(interp, newcmd, 0, 2, 1, newobjv) != TCL_OK)
 	return TCL_ERROR;
       if (Tcl_GlobalEvalObj(interp, newcmd) != TCL_OK)
 	return TCL_ERROR;
